package com.semarchy.mdm.client.samples;

import java.text.MessageFormat;
import java.util.List;
import java.util.Locale;

import com.semarchy.mdm.client.IDataEditionConnection;
import com.semarchy.mdm.client.IMDMConnection;
import com.semarchy.mdm.client.MDMConnectionFactory;
import com.semarchy.mdm.runtime.model.common.IAttribute;
import com.semarchy.mdm.runtime.model.dataaccess.IDataAccessModel;
import com.semarchy.mdm.runtime.model.dataaccess.IView;
import com.semarchy.mdm.runtime.model.dataaccess.IViewAttribute;
import com.semarchy.mdm.runtime.model.dataaccess.ViewTypes;
import com.semarchy.mdm.runtime.model.logical.IEntity;
import com.semarchy.mdm.runtime.model.logical.IEntityAttribute;
import com.semarchy.mdm.runtime.model.logical.IModel;
import com.semarchy.mdm.runtime.platform.DataEditionID;

/**
 * This sample demonstrate how:
 * <ul>
 * <li>Create an {@link IDataEditionConnection} for a given
 * {@link DataEditionID}
 * <li>Browse the {@link IModel} and {@link IDataAccessModel} associated to the
 * Data Edition
 * </ul>
 * 
 * @author sarod
 * 
 */
public class Sample2_ListEntitiesAndViewsSample {

	public static void main(String[] args) {

		// Connect to the MDM instance
		IMDMConnection conn = MDMConnectionFactory.connect(
				SamplesConstants.SEMARCHY_URL, SamplesConstants.USERNAME,
				SamplesConstants.PASSWORD);

		// Connect to the DataEdition 
		IDataEditionConnection dataEditionConnection = conn
				.createDataEditionConnection(SamplesConstants.GS_DATAEDITION);

		// Use the IModel to list the IEntity
		IModel model = dataEditionConnection.getLogicalModel();

		List<IEntity> entities = model.getEntities();
		Locale locale = Locale.getDefault();
		System.out.println(MessageFormat.format(
				"Display Model information using {0} Locale",
				locale.getDisplayName()));
		System.out.println(MessageFormat.format("Model contains {0} entities:",
				entities.size()));

		for (IEntity iEntity : entities) {
			System.out.println(" - Name: " + iEntity.getName());
			System.out.println("\t - Label: "
					+ model.getLabelProvider().getLabel(iEntity, locale));
			System.out.println("\t - Desc: "
					+ model.getLabelProvider().getDescription(iEntity, locale));

			for (IEntityAttribute entityAttr : iEntity.getAttributes()) {
				System.out.println("\t\t- " + entityAttr.getName() + " ("
						+ model.getLabelProvider().getLabel(entityAttr, locale)
						+ ")");
			}
		}

		// Use the IDataAccessModel to list the Golden IView
		IDataAccessModel dataAccessModel = dataEditionConnection
				.getDataAccessModel();

		System.out.println("List Golden Views Attributes: ");

		for (IView iView : dataAccessModel.getViews()) {
			if (iView.getViewType().equals(
					ViewTypes.GD)) {
				System.out.println(" - View Name: " + iView.getViewName()
						+ " (on Entity " + iView.getEntity().getName() + ")");

				System.out.println("\t - Label: "
						+ dataAccessModel.getLabelProvider().getLabel(iView,
								locale));
				System.out.println("\t - Desc: "
						+ dataAccessModel.getLabelProvider().getDescription(
								iView, locale));

				for (IViewAttribute<? extends IAttribute> viewAttr : iView
						.getAttributes()) {
					System.out.println("\t\t- "
							+ viewAttr.getName()
							+ " ("
							+ dataAccessModel.getLabelProvider().getLabel(
									viewAttr, locale) + ")");
				}
			}
		}

	}
}
